@@ -8,11 +8,16 @@
 @File    : _version.py
 @Desc    : 
 """
+import os
 
-VERSION = "0.2.18"
+VERSION = os.environ.get('VERSION', "0.2.19")
 
 
 def get_versions():
+    file = os.path.join(os.path.split(os.path.realpath(__file__))[0], "_version")
+    if os.path.exists(file):
+        with open(file) as f:
+            return f.readline()
     return VERSION
 
 
